@@ -20,6 +20,15 @@ module Vagrant
             config.customize 'mount.entry', '/sys/fs/pstore sys/fs/pstore none bind,optional 0 0'
           end
 
+          # Make selinux read-only, see
+          # https://github.com/fgrehm/vagrant-lxc/issues/301
+          if Dir.exists?('/sys/fs/selinux')
+            config.customize 'mount.entry', '/sys/fs/selinux sys/fs/selinux none bind,ro 0 0'
+          end
+
+          # Make /tmp a tmpfs to prevent init scripts from nuking synced folders mounted in here
+          config.customize 'mount.entry', 'tmpfs tmp tmpfs nodev,nosuid,size=2G 0 0'
+
           env[:ui].info I18n.t("vagrant_lxc.messages.starting")
           env[:machine].provider.driver.start(config.customizations)
 
